@@ -48,7 +48,7 @@ class GoTestTest(CliTestCase):
     @mock.patch.dict(os.environ, {"LAUNCHABLE_TOKEN": CliTestCase.launchable_token})
     def test_record_tests_with_session(self):
         result = self.cli('record', 'tests',  '--session',
-                          self.session, 'go-test', str(self.test_files_dir) + "/")
+                          self.session, 'go-test', str(self.test_files_dir.joinpath('reportv1')) + "/")
         self.assertEqual(result.exit_code, 0)
 
         self.assertIn(
@@ -73,7 +73,7 @@ class GoTestTest(CliTestCase):
         write_build(self.build_name)
 
         result = self.cli('record', 'tests', 'go-test',
-                          str(self.test_files_dir) + "/")
+                          str(self.test_files_dir.joinpath('reportv1')) + "/")
         self.assertEqual(result.exit_code, 0)
 
         self.assertEqual(read_session(self.build_name), self.session)
@@ -91,3 +91,25 @@ class GoTestTest(CliTestCase):
 
         self.assertIn(
             'close', responses.calls[4].request.url, 'call close API')
+
+    @responses.activate
+    @mock.patch.dict(os.environ, {"LAUNCHABLE_TOKEN": CliTestCase.launchable_token})
+    def test_record_tests_v2(self):
+        result = self.cli('record', 'tests',  '--session',
+                          self.session, 'go-test', str(self.test_files_dir.joinpath('reportv2')) + "/")
+        self.assertEqual(result.exit_code, 0)
+
+        self.assertIn(
+            'events', responses.calls[1].request.url, 'call events API')
+        payload = json.loads(gzip.decompress(
+            responses.calls[1].request.body).decode())
+        # Remove timestamp because it depends on the machine clock
+        for c in payload['events']:
+            del c['created_at']
+
+        expected = self.load_json_from_file(
+            self.test_files_dir.joinpath('record_test_result.json'))
+        self.assert_json_orderless_equal(expected, payload)
+
+        self.assertIn(
+            'close', responses.calls[3].request.url, 'call close API')
